from setuptools import setup

setup(name='distributions_PR',
      version='0.1',
      description='Gaussian distributions',
      packages=['distributions_PR'],
      author=['Pouya'],
      zip_safe=False)
